import { Alarm } from "./alarm";
import { Metric } from "./metric";
import { ConcreteWidget } from "./widget";
/**
 * Basic properties for widgets that display metrics
 */
export interface MetricWidgetProps {
    /**
     * Title for the graph
     */
    readonly title?: string;
    /**
     * The region the metrics of this graph should be taken from
     *
     * @default Current region
     */
    readonly region?: string;
    /**
     * Width of the widget, in a grid of 24 units wide
     *
     * @default 6
     */
    readonly width?: number;
    /**
     * Height of the widget
     *
     * @default Depends on the type of widget
     */
    readonly height?: number;
}
/**
 * Properties for an AlarmWidget
 */
export interface AlarmWidgetProps extends MetricWidgetProps {
    /**
     * The alarm to show
     */
    readonly alarm: Alarm;
    /**
     * Range of left Y axis
     *
     * @default 0..automatic
     */
    readonly leftAxisRange?: YAxisRange;
}
/**
 * Display the metric associated with an alarm, including the alarm line
 */
export declare class AlarmWidget extends ConcreteWidget {
    private readonly props;
    constructor(props: AlarmWidgetProps);
    toJson(): any[];
}
/**
 * Properties for a GraphWidget
 */
export interface GraphWidgetProps extends MetricWidgetProps {
    /**
     * Metrics to display on left Y axis
     */
    readonly left?: Metric[];
    /**
     * Metrics to display on right Y axis
     */
    readonly right?: Metric[];
    /**
     * Annotations for the left Y axis
     */
    readonly leftAnnotations?: HorizontalAnnotation[];
    /**
     * Annotations for the right Y axis
     */
    readonly rightAnnotations?: HorizontalAnnotation[];
    /**
     * Whether the graph should be shown as stacked lines
     */
    readonly stacked?: boolean;
    /**
     * Range of left Y axis
     *
     * @default 0..automatic
     */
    readonly leftAxisRange?: YAxisRange;
    /**
     * Range of right Y axis
     *
     * @default 0..automatic
     */
    readonly rightAxisRange?: YAxisRange;
}
/**
 * A dashboard widget that displays metrics
 */
export declare class GraphWidget extends ConcreteWidget {
    private readonly props;
    constructor(props: GraphWidgetProps);
    toJson(): any[];
}
/**
 * Properties for a SingleValueWidget
 */
export interface SingleValueWidgetProps extends MetricWidgetProps {
    /**
     * Metrics to display
     */
    readonly metrics: Metric[];
}
/**
 * A dashboard widget that displays the most recent value for every metric
 */
export declare class SingleValueWidget extends ConcreteWidget {
    private readonly props;
    constructor(props: SingleValueWidgetProps);
    toJson(): any[];
}
/**
 * A minimum and maximum value for either the left or right Y axis
 */
export interface YAxisRange {
    /**
     * The minimum value
     *
     * @default Automatic
     */
    readonly min?: number;
    /**
     * The maximum value
     *
     * @default Automatic
     */
    readonly max?: number;
}
/**
 * Horizontal annotation to be added to a graph
 */
export interface HorizontalAnnotation {
    /**
     * The value of the annotation
     */
    readonly value: number;
    /**
     * Label for the annotation
     *
     * @default No label
     */
    readonly label?: string;
    /**
     * Hex color code to be used for the annotation
     *
     * @default Automatic color
     */
    readonly color?: string;
    /**
     * Add shading above or below the annotation
     *
     * @default No shading
     */
    readonly fill?: Shading;
    /**
     * Whether the annotation is visible
     *
     * @default true
     */
    readonly visible?: boolean;
}
export declare enum Shading {
    /**
     * Don't add shading
     */
    None = "none",
    /**
     * Add shading above the annotation
     */
    Above = "above",
    /**
     * Add shading below the annotation
     */
    Below = "below"
}
